Error

Enum Error 

pub enum Error {
Show 37 variants NoFolderPassword(VaultId), NoDatabase, NotFile(PathBuf), NoDefaultFolder, NoOpenFolder, PemEncoding, NoArchive, NotArchived, AlreadyArchived, NoContactsFolder, NotContact, JsonPathQueryEmpty(Vec<String>), NoClipboard, TryFromSlice(TryFromSliceError), Core(Error), Authentication(AuthenticationError), Search(Error), Vault(Error), Login(Error), Signer(Error), Sync(Error), Password(Error), BackendStorage(StorageError), Storage(Error), Backend(Error), Database(Error), Archive(Error), Io(Error), Json(Error), Uuid(Error), Hex(FromHexError), Vcard(Error), Clipboard(Error), TimeZone(Error), StripPrefix(StripPrefixError), Migrate(Error), BackupArchive(Error),
}
Error generated by the account library.

Variants



NoFolderPassword(VaultId)

Error generated when a folder password could not be located.



NoDatabase

Error generated when a database is required.



NotFile(PathBuf)

Error generated when a path is not a file.



NoDefaultFolder

Error generated when no default folder is available.



NoOpenFolder

Error generated when an open folder is expected.



PemEncoding

Error generated when a PEM-encoded certificate is invalid.



NoArchive

Error generated when an archive folder is not available.



NotArchived

Error generated when attempting to unarchive a secret that is not archived.



AlreadyArchived

Error generated when attempting to archive a secret that is already archived.



NoContactsFolder

Error generated when a contacts folder is not available.



NotContact

Error generated when a secret is not a contact secret.



JsonPathQueryEmpty(Vec<String>)

Error generated by the JSON path library when no nodes matched.



NoClipboard

Error when no clipboard is configured.



TryFromSlice(TryFromSliceError)

Error generated converting to fixed length slice.



Core(Error)

Error generated by the core library.



Authentication(AuthenticationError)

Authentication errors.



Search(Error)

Error generated by the search library.



Vault(Error)

Error generated by the vault library.



Login(Error)

Error generated by the login library.



Signer(Error)

Error generated by the signer library.



Sync(Error)

Error generated by the sync library.



Password(Error)

Error generated by the password library.



BackendStorage(StorageError)

Error generated by the backend storage .



Storage(Error)

Error generated by the storage library.



Backend(Error)

Error generated by the backend library.



Database(Error)

Error generated by the database library.



Archive(Error)

Error generated by the database archive library.



Io(Error)

Error generated by the IO module.



Json(Error)

Error generated by the JSON library.



Uuid(Error)

Error generated by the UUID library.



Hex(FromHexError)

Error generated by the hexadecimal library.



Vcard(Error)

Error generated by the VCard library.



Clipboard(Error)

Error generated by the clipboard library.



TimeZone(Error)

Error generated attempting to detect the system time zone.



StripPrefix(StripPrefixError)

Error generated when stripping a prefix from a path.



Migrate(Error)

Error generated by the migrate library.



BackupArchive(Error)

Error generated by the backup archive library.