pub struct CipherComparison {
pub cipher: Cipher,
pub kdf: KeyDerivation,
pub identity: Option<Summary>,
pub folders: Vec<Summary>,
}Expand description
Comparison between an existing cipher and a target cipher.
Used to determine which folders to modify when changing the cipher for an account.
Fields
cipher: CipherCipher to convert to.
kdf: KeyDerivationKey derivation function.
identity: Option<Summary>Identity folder conversion info.
folders: Vec<Summary>User folders conversion info.
Implementations